summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetepasswordedaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetepasswordedaccount.h')
-rw-r--r--kopete/libkopete/kopetepasswordedaccount.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/libkopete/kopetepasswordedaccount.h b/kopete/libkopete/kopetepasswordedaccount.h
index 4be22016..210adbd4 100644
--- a/kopete/libkopete/kopetepasswordedaccount.h
+++ b/kopete/libkopete/kopetepasswordedaccount.h
@@ -74,15 +74,15 @@ public:
/**
* @brief Go online for this service.
*
* @param initialtqStatus is the status to connect with. If it is an invalid status for this
* account, the default online for the account should be used.
*/
- void connect( const OnlineStatus& initialtqStatus );
+ void connect( const OnlineStatus& initialStatus );
/**
* \brief Get the initial status
*/
- OnlineStatus initialtqStatus();
+ OnlineStatus initialStatus();
/**
* @brief Remove the account from the server.
@@ -74,15 +74,15 @@ public:
* @brief Go online for this service.
*
- * @param initialtqStatus is the status to connect with. If it is an invalid status for this
+ * @param initialStatus is the status to connect with. If it is an invalid status for this
* account, the default online for the account should be used.
*/